PgNtexSession

Struct PgNtexSession 

pub struct PgNtexSession<SE: StateEncryption + Clone>(/* private fields */);

Implementations

Source

impl<SE: StateEncryption + Clone> PgNtexSession<SE>

pub fn new( key: impl AsRef<[u8]>, encryption_engine: Option<SE>, pooled_connection: Arc<Pool<ConnectionManager<PgConnection>>>, ) -> Self

Construct new signed PgNtexSession instance.

You can use UUID v4 as encryption key. Panics if key length is less than 32 bytes. pooled_connection is a Pool of Postgres Connection Manager. Check r2d2 Pool sample and ConnectionManager sample

pub fn path<S: Into<String>>(self, value: S) -> Self

Sets the path field in the session cookie being built.

pub fn name<S: Into<String>>(self, value: S) -> Self

Sets the name field in the session cookie being built.

pub fn domain<S: Into<String>>(self, value: S) -> Self

Sets the domain field in the session cookie being built.

pub fn secure(self, value: bool) -> Self

Sets the secure field in the session cookie being built.

If the secure field is set, a cookie will only be transmitted when the connection is secure - i.e. https

pub fn http_only(self, value: bool) -> Self

Sets the http_only field in the session cookie being built.

pub fn same_site(self, value: SameSite) -> Self

Sets the same_site field in the session cookie being built.

pub fn max_age(self, seconds: u64) -> Self

Sets the max-age field in the session cookie being built.

pub fn max_age_time(self, value: Duration) -> Self

Sets the max-age field in the session cookie being built.

pub fn expires_in(self, seconds: u64) -> Self

Sets the expires field in the session cookie being built.

pub fn expires_in_time(self, value: Duration) -> Self

Sets the expires field in the session cookie being built.