pub struct PgNtexSession<SE: StateEncryption + Clone>(/* private fields */);Implementations
Sourceimpl<SE: StateEncryption + Clone> PgNtexSession<SE>
impl<SE: StateEncryption + Clone> PgNtexSession<SE>
Sourcepub fn new(
key: impl AsRef<[u8]>,
encryption_engine: Option<SE>,
pooled_connection: Arc<Pool<ConnectionManager<PgConnection>>>,
) -> Self
pub fn new( key: impl AsRef<[u8]>, encryption_engine: Option<SE>, pooled_connection: Arc<Pool<ConnectionManager<PgConnection>>>, ) -> Self
Construct new signed PgNtexSession instance.
You can use UUID v4 as encryption key.
Panics if key length is less than 32 bytes.
pooled_connection is a Pool of Postgres Connection Manager. Check r2d2 Pool sample and ConnectionManager sample
Sourcepub fn path<S: Into<String>>(self, value: S) -> Self
pub fn path<S: Into<String>>(self, value: S) -> Self
Sets the path field in the session cookie being built.
Sourcepub fn name<S: Into<String>>(self, value: S) -> Self
pub fn name<S: Into<String>>(self, value: S) -> Self
Sets the name field in the session cookie being built.
Sourcepub fn domain<S: Into<String>>(self, value: S) -> Self
pub fn domain<S: Into<String>>(self, value: S) -> Self
Sets the domain field in the session cookie being built.
Sourcepub fn secure(self, value: bool) -> Self
pub fn secure(self, value: bool) -> Self
Sets the secure field in the session cookie being built.
If the secure field is set, a cookie will only be transmitted when the
connection is secure - i.e. https
Sourcepub fn http_only(self, value: bool) -> Self
pub fn http_only(self, value: bool) -> Self
Sets the http_only field in the session cookie being built.
Sourcepub fn same_site(self, value: SameSite) -> Self
pub fn same_site(self, value: SameSite) -> Self
Sets the same_site field in the session cookie being built.
Sourcepub fn max_age(self, seconds: u64) -> Self
pub fn max_age(self, seconds: u64) -> Self
Sets the max-age field in the session cookie being built.
Sourcepub fn max_age_time(self, value: Duration) -> Self
pub fn max_age_time(self, value: Duration) -> Self
Sets the max-age field in the session cookie being built.
Sourcepub fn expires_in(self, seconds: u64) -> Self
pub fn expires_in(self, seconds: u64) -> Self
Sets the expires field in the session cookie being built.
Sourcepub fn expires_in_time(self, value: Duration) -> Self
pub fn expires_in_time(self, value: Duration) -> Self
Sets the expires field in the session cookie being built.